#!/bin/ksh

# process Acid Rain MECT Data
#  bc = basecase = day specific
#  bl = baseline = generic
# tx_osd_fy18b_MECT c14jul2008 (0801) new afs c11jul2008
#                   c22jul2008 new afs c22jul2008
#                   c01aug2008 new afs c01aug2008
# tx_osd_fy18c_MECT c27aug2008 (0801) new afs c25aug2008
# tx_osd_fy18c_CAIR c11sep2008 (0801) new afs c10sep2008
# tx_osd_fy18e_CAIR c05jun2009 (0801) new afs c02jun2009
# tx_osd_fy18f_CAIR c18nov2009 (0801) new afs c13nov2009
# tx_osd_fy18g_CAIR c20nov2009 (0801) new afs c20nov2009
# tx_osd_fy18h_CAIR c04dec2009 (0801) new afs c02dec2009

 USER_PATH=/ei/area/data/userin_files
 export USER_PATH

 today=`date +%y%b%d`
 PT_PATH=/ei/point/EPS3
 export PT_PATH

 EPS3_PATH=/usr/local/pub/eps3/src
 export EPS3_PATH

 for county_switch in no8co
  do

 case $county_switch in
  '8co')    county_group=hgb_8co ;;
  'no8co')  county_group=no_hgb_8co ;;
 esac

 run_type=tx_osd
 yyX=18h_CAIR
 scenario=tx_osd_fy${yyX}_${county_group}

#grid=hg_01km
#grid=hg_02km
#grid=reg_12km
 grid=eus_36km

# below c11jul2007; 1st eps run 07aug2007
 tmprof_xref=tmprl.xref.tx_osd_2005_v4a
 tmprof=tmprl.profs.tx_osd_2005_v4a

 ugrid=${grid}_exole_${county_group} # forces MECT elevated

  case $grid in
   'hg_02km')  ugrid=${grid}_${county_switch} ;;
   'hg_04km')  ugrid=${grid}_${county_switch} ;;
  esac

 for spec in cb05
  do

#case $spec in
# 'cb05')  fac_v=2005v4a.pt.all.etha ;;
# 's99')   fac_v=2000v15c.pt.all ;;
#esac

 splitfac=`get_file "/ei/point/EPS3/chmspl/emscvt/splitfac.cb05.2006v4bHc.pt.all.etha.04Mar0*"`
#splitfac=`get_file "/ei/point/speciation/emscvt/output_cb05/splitfac.cb05.HECTv2.08Jul2*"`
#splitfac=`get_file "/ei/point/EPS3/chmspl/emscvt/splitfac.$spec.$fac_v.*"`
#splitfac=/ei/point/EPS3/chmspl/emscvt/splitfac.$spec.2000v15b2.pt.all.23Sep05

 chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2006v4bHc.pt.all.04Mar09.FACILITY.09Jun*"`
#chmprof_xref=`get_file "/ei/point/stars/2005/data/emscvt_inputs/xref.voc.eps3f.2005_v4a_w_HECT_v2.pt.FACILITY"`
#chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2005v4a.pt.all.*"`


 for yymmdd in \
  060801 \

 do

case $yymmdd in
#050601) afsin=afs.tx_osd.by05b_maySI;;
 050622) afsin=afs.tx_osd.fy${yyX}.$county_group;;
 060801) afsin=afs.tx_osd.fy${yyX}.$county_group;;
esac

 echo
 echo "today  yymmdd  grid scenario afsin ugrid"
 echo $today  $yymmdd  $grid $scenario $afsin $ugrid

 cd $PT_PATH/prepnt/$run_type
  run.prepnt.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $afsin $ugrid

 cd $PT_PATH/chmspl/$run_type
  run.chmspl.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $chmprof_xref $splitfac $ugrid $scenario 'prepnt'

 cd $PT_PATH/tmprl/$run_type
  run.tmprl.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $tmprof_xref $tmprof $ugrid

 cd $PT_PATH/grdem/$run_type
# run.grdem.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid

 if [ "$grid" = eus_36km ]
  then
 echo $grid
 cd $PT_PATH/pstpnt/$run_type
  run.pstpnt.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid

 cd $PT_PATH/pigems/$run_type
  run.pigems.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid
 fi

 done
 done
done
exit

#if [[ $grid = eus_36km ]]; then
# case $run_type in
#  'tx')      ugrid=${grid}_tx ;;
#  'tx_ard')  ugrid=${grid}_egu ;;
#  'tx_egu')  ugrid=${grid}_egu ;;
#  'tx_osd')  ugrid=${grid}_${county_group} ;;
#  'la')      ugrid=${grid}_la ;;
#  'reg')     ugrid=$grid ;;
#  'os')      ugrid=${grid}_os ;;
#  'mex')     ugrid=${grid}_mex ;;
# esac
#fi

#if [[ $grid = reg_12km ]]; then
# case $run_type in
#  'tx')      ugrid=${grid}_tx ;;
#  'tx_osd')  ugrid=${grid}_${county_group} ;;
#  'la')      ugrid=${grid}_la ;;
#  'reg')     ugrid=$grid ;;
#  'os')      ugrid=${grid}_os ;;
#  'mex')     ugrid=${grid}_mex ;;
# esac
#fi
