#!/bin/ksh

# process Acid Rain Data
#  bc = basecase = day specific
#  bl = baseline = generic
# tx_osd_fy18b_mHMECT c14jul2008 (0801) new afs c11jul2008
#   c21jul2008 (0801) new afs c21jul2008 - updated HECTv2
#   c22jul2008 (0801) new afs c22jul2008 - updated HECTv2
#   c23jul2008 (0801) new afs c23jul2008 - small BPA fix - no8co change only
#   c01aug2008 (0801) re-run - same - elevated 8co only
# tx_osd_fy18b_mHMECTnCAIR c27aug2008 (0801) new afs c25aug2008 - also do nozeros
# tx_osd_fy18b_no_rules c03sep2008 new afs c03sep2008
# tx_osd_fy18c_no_rules c05dec2008 new afs c05dec2008 - now has growth
# tx_osd_fy18d_no_rules c27jan2009 new afs c27jan2009 by Marvin - only growth from bank - corrected
#                       c30jan2009 new afs c30jan2009 by Marvin - fix on 8co
#                       c06feb2009 new afs c05feb2009 by Marvin
# tx_osd_fy18e_no_rules c31mar2009 new afs c25mar2009 by Marvin
# tx_osd_fy18f_no_rules c03jun2009 new afs c02jun2009 by Marvin - based on 2006, removed TLL
#                       c04jun2009 new afs c04jun2009 by Marvin SAS fix picks TIPI 2006to18 v. REMI 02to18; less growth !
#                                  try 2006 emscvt files
# tx_osd_fy18g_no_rules c22jun2009 new afs c22jun2009 by Marvin
# tx_osd_fy18h_no_rules c18nov2009 new afs c17nov2009 by Marvin
# tx_osd_fy18i_no_rules c20nov2009 new afs c20nov2009 by Marvin - better DERCs
# tx_osd_fy18j_no_rules c04dec2009 new afs c02dec2009 by Marvin - growth ans cap tweaks

 USER_PATH=/ei/area/data/userin_files
 export USER_PATH

 today=`date +%y%b%d`
 PT_PATH=/ei/point/EPS3
 export PT_PATH

 EPS3_PATH=/usr/local/pub/eps3/src
 export EPS3_PATH

#for county_switch in     no8co
#for county_switch in 8co
 for county_switch in 8co no8co
  do

 case $county_switch in
  '8co')    county_group=hgb_8co ;;
  'no8co')  county_group=no_hgb_8co ;;
 esac

 run_type=tx_osd
 yyX=18j_no_rules
 scenario=tx_osd_fy${yyX}_${county_group}

##rid=hg_01km
#grid=hg_02km
#grid=reg_12km
#grid=eus_36km

 for grid in \
   hg_02km \
   reg_12km \
   eus_36km \

  do

# below c11jul2007; 1st eps run 07aug2007
 tmprof_xref=tmprl.xref.tx_osd_2005_v4a
 tmprof=tmprl.profs.tx_osd_2005_v4a

 ugrid=${grid}_${county_group}

  case $grid in
   'hg_02km')  ugrid=${grid}_${county_switch} ;;
   'hg_04km')  ugrid=${grid}_${county_switch} ;;
  esac

 for spec in cb05
  do

#case $spec in
# 'cb4')   fac_v=2005v3a_2004v4d.pt.all ;;
# 'cb05')  fac_v=2005v4a.pt.all.etha ;;
# 's99')   fac_v=2000v15c.pt.all ;;
#esac

 splitfac=`get_file "/ei/point/EPS3/chmspl/emscvt/splitfac.cb05.2006v4bHc.pt.all.etha.04Mar0*"`
#splitfac=`get_file "/ei/point/speciation/emscvt/output_cb05/splitfac.cb05.2006v4bHc.pt.all.04Mar0*"`
#splitfac=`get_file "/ei/point/speciation/emscvt/output_cb05/splitfac.cb05.HECTv2pEPA.08Jul2*"`
#splitfac=/ei/point/speciation/emscvt/output_cb05/splitfac.cb05.HECTpEPA.08Jul15
#splitfac=/ei/point/speciation/emscvt/output_cb05/splitfac.cb05.HECT.08Jul14
#splitfac=`get_file "/ei/point/EPS3/chmspl/emscvt/splitfac.$spec.$fac_v.*"`

 chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2006v4bHc.pt.all.04Mar09.FACILITY.09Jun*"`
#chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2005_v4a_w_HECT_v2.pt.FACILITY.plusEPA.08*"`
#chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2005_v4a_w_HECT.pt.FACILITY.plusEPA.08*"`
#chmprof_xref=/ei/point/stars/2005/data/emscvt_inputs/xref.voc.eps3f.2005_v4a_w_HECT.pt.FACILITY

#case $spec in
# 'cb05')  splitfac=`get_file "/ei/point/speciation/emscvt/output_${spec}/splitfac.$spec.may2005si.07*"`;;
#esac

#  wed.   sat.   sun.  for jun05 episode
# 050622 050625 050626 \
# 050601
# 050728
 for yymmdd in \
  060801 \

 do

case $yymmdd in
#050601) afsin=afs.tx_osd.by05b_maySI;;
 050622) afsin=afs.tx_osd.fy${yyX}.$county_group;;
 060801) afsin=afs.tx_osd.fy${yyX}.$county_group;;
esac

#afsin=afs.avg2005ar_egu_0901_2kOSDv3_000901_nonzero.CI0012D.lcp

 echo
 echo "today  yymmdd  grid scenario afsin ugrid"
 echo $today  $yymmdd  $grid $scenario $afsin $ugrid

 cd $PT_PATH/prepnt/$run_type
  run.prepnt.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $afsin $ugrid

 cd $PT_PATH/chmspl/$run_type
  run.chmspl.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $chmprof_xref $splitfac $ugrid $scenario 'prepnt'

 cd $PT_PATH/tmprl/$run_type
  run.tmprl.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $tmprof_xref $tmprof $ugrid

 cd $PT_PATH/grdem/$run_type
  run.grdem.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid

 if [ "$grid" = eus_36km ]
  then
 echo $grid
 cd $PT_PATH/pstpnt/$run_type
  run.pstpnt.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid

 cd $PT_PATH/pigems/$run_type
  run.pigems.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid
 fi

 done
 done
done
done
exit

#if [[ $grid = eus_36km ]]; then
# case $run_type in
#  'tx')      ugrid=${grid}_tx ;;
#  'tx_ard')  ugrid=${grid}_egu ;;
#  'tx_egu')  ugrid=${grid}_egu ;;
#  'tx_osd')  ugrid=${grid}_${county_group} ;;
#  'la')      ugrid=${grid}_la ;;
#  'reg')     ugrid=$grid ;;
#  'os')      ugrid=${grid}_os ;;
#  'mex')     ugrid=${grid}_mex ;;
# esac
#fi

#if [[ $grid = reg_12km ]]; then
# case $run_type in
#  'tx')      ugrid=${grid}_tx ;;
#  'tx_osd')  ugrid=${grid}_${county_group} ;;
#  'la')      ugrid=${grid}_la ;;
#  'reg')     ugrid=$grid ;;
#  'os')      ugrid=${grid}_os ;;
#  'mex')     ugrid=${grid}_mex ;;
# esac
#fi
